import { AntlrParser, AntlrRuleError, AntlrRuleWrapper, AntlrTokenWrapper } from 'antlr4-helper';
export declare const ACTIVE_HINT_CLASS = "CodeMirror-hint-active";
export declare const HINT_CLASS = "CodeMirror-hint";
export declare const HINTS_CLASS = "CodeMirror-hints";
import { Editor } from 'codemirror';
import { AntlrEditor } from '../../editor/antlr-editor';
import { RuleDecoration } from '../../decoration/rule-decoration';
import { KeyMapping } from '../../key-mapping/key-mapping';
import { TokenDecoration } from '../../decoration/token-decoration';
import { EditorPosition } from '../../types';
import { AutoCompleteEvent } from '../../event/auto-complete-event';
import { Completion } from '../../completion/completion';
import { CompletionPopup } from '../../completion/completion-popup';
import { EditorChangeEvent } from '../../event/editor-change-event';
import { Placeholder } from '../../placeholder/placeholder';
import { BookmarkDecoration } from '../../bookmark/bookmark';
export declare class CodeMirrorEditor implements AntlrEditor {
    private parser;
    private domContainer?;
    editorImplementation: Editor;
    private defaultTokenStyles;
    private defaultRuleStyles;
    private cursorPosition;
    private displaySingleError;
    private changeSubject;
    private ruleDecorations;
    private placeholdersRendered;
    private bookmarkDecorations;
    private tokenDecorations;
    private ruleErrorMessageHandlers;
    private autoCompleteSubject;
    private displayDecorations;
    private autoCompletionHandler;
    private currentCompletionPopup;
    private lastChangeEvent;
    private defaultHintMapping;
    private selections;
    private hintContainer;
    private customErrors;
    private validators;
    private setValueEvent;
    private defaultCursorBlinkingRate;
    constructor(parser: AntlrParser, domContainer?: HTMLElement);
    setHintContainer(el: HTMLElement): void;
    replaceRange(range: [EditorPosition, EditorPosition], text: string): [EditorPosition, EditorPosition];
    setText(text: string): void;
    update(): void;
    getText(): string;
    getParser(): AntlrParser;
    setParser(parser: AntlrParser): void;
    addKeyMapping(mapping: KeyMapping): void;
    removeKeyMapping(mapping: KeyMapping): void;
    focus(): void;
    createRuleDecoration(rule: AntlrRuleWrapper, domElement: HTMLElement): RuleDecoration;
    getRuleDecoration(rule: AntlrRuleWrapper): RuleDecoration | undefined;
    createTokenDecoration(token: AntlrTokenWrapper, domElement: HTMLElement): TokenDecoration;
    getTokenDecoration(token: AntlrTokenWrapper): TokenDecoration | undefined;
    getDomElement(): HTMLElement;
    setTheme(theme: string): void;
    getTheme(): string;
    setDefaultTokenStyles(styles: {
        [tokenName: string]: string;
    }): void;
    setDefaultRuleStyles(styles: {
        [ruleName: string]: string;
    }): void;
    updateCursorPosition(): void;
    setDisplayEditorErrors(display: boolean): void;
    getDisplayEditorErrors(): boolean;
    setEditorPlaceholderText(text: string): void;
    setReadOnly(readOnly: boolean): void;
    getReadOnly(): boolean;
    setStyleActiveLine(styleActiveLine: boolean): void;
    getStyleActiveLine(): boolean;
    setLineWrapping(lineWrapping: boolean): void;
    getLineWrapping(): boolean;
    getEditorPlaceholderText(): string;
    setDisplayOnlyRelevantEditorErrors(display: boolean): void;
    getDisplayOnlyRelevantEditorErrors(): boolean;
    setShowLineNumbers(show: boolean): void;
    getShowLineNumbers(): boolean;
    addStyleToRule(rule: AntlrRuleWrapper, css: string): void;
    addClassToRule(rule: AntlrRuleWrapper, cssClass: string): void;
    addStyleToToken(token: AntlrTokenWrapper, css: string): void;
    addClassToToken(token: AntlrTokenWrapper, cssClass: string): void;
    addAutoCompleteListener(rule: string, listener: (event: AutoCompleteEvent) => void): void;
    addChangeListener(listener: (event: EditorChangeEvent) => void): void;
    setCursorPosition(position: EditorPosition): void;
    getCursorPosition(): EditorPosition;
    defineErrorMessage(ruleOrMessage: string, handler: (error: AntlrRuleError) => string): void;
    getEditorErrors(): AntlrRuleError[];
    getRelevantEditorError(): AntlrRuleError;
    setDisplayDecorations(display: boolean): void;
    getDisplayDecorations(): boolean;
    showCompletions(completions: Completion[]): CompletionPopup;
    createRuleCompletion(baseCompletion: Completion, rule: AntlrRuleWrapper): Completion;
    triggerAutoCompletionEvent(event: AutoCompleteEvent): void;
    hasRenderedPlaceholders(): boolean;
    createPlaceholder(range: [EditorPosition, EditorPosition]): Placeholder;
    createRulePlaceholder(rule: AntlrRuleWrapper): Placeholder;
    createBookmarkDecoration(start: EditorPosition, dom: HTMLElement, insertLeft?: boolean): BookmarkDecoration;
    hasSelections(): boolean;
    addTokenSelection(token: AntlrTokenWrapper): void;
    addRuleSelection(rule: AntlrRuleWrapper): void;
    addSelection(range: [EditorPosition, EditorPosition]): void;
    getSelections(): Array<[EditorPosition, EditorPosition]>;
    setEnableVim(enable: boolean): void;
    getEnableVim(): boolean;
    getRuleByName(ruleName: string): AntlrRuleWrapper;
    getRulesByName(ruleName: string): AntlrRuleWrapper[];
    getAllRules(): AntlrRuleWrapper[];
    getAllTokens(): AntlrTokenWrapper[];
    addEditorValidator(validator: (rule: AntlrRuleWrapper) => AntlrRuleError): void;
    hasErrors(): boolean;
    createRuleError(rule?: AntlrRuleWrapper): AntlrRuleError;
    validate(): void;
    clearAllCompletions(): void;
    private styleToken;
    private styleRule;
    private mapParseErrorToCodeMirrorError;
    private attachBasicEvents;
    private hideAllDecorations;
    private showAllDecorations;
}
