"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var CodeMirrorRuleDecoration = /** @class */ (function () {
    function CodeMirrorRuleDecoration(editor, rule, domElement) {
        var _this = this;
        this.editor = editor;
        this.rule = rule;
        this.domElement = domElement;
        this.clearOnEnter = true;
        this.toggleOnExit = true;
        this.hidden = false;
        var changed = false;
        this.cursorActivityFunction = function () {
            if (changed) {
                changed = false;
            }
            else if (_this.rule.exists()) {
                var pos = _this.editor.getCursorPosition();
                var range = _this.rule.getRange();
                if (_this.rule.inRange(pos) || (range[1].line === pos.line && range[1].column === pos.column)) {
                    _this.handleRuleWhenWithin();
                }
                else {
                    if (_this.hidden && _this.toggleOnExit) {
                        _this.show();
                    }
                }
            }
        };
        this.changeEventFunction = function () {
            changed = true;
        };
        //
        // Make sure the rule exists, before defaulting on a show
        //
        if (this.editor.getDisplayDecorations()) {
            this.show();
            this.cursorActivityFunction();
        }
        else {
            this.hidden = true;
        }
    }
    CodeMirrorRuleDecoration.prototype.getRule = function () {
        return this.rule;
    };
    CodeMirrorRuleDecoration.prototype.getDomElement = function () {
        return this.domElement;
    };
    CodeMirrorRuleDecoration.prototype.isHidden = function () {
        return this.hidden;
    };
    CodeMirrorRuleDecoration.prototype.show = function () {
        if (!this.mark) {
            var ruleRange = this.rule.getRange();
            this.mark = this.editor.editorImplementation.getDoc()
                .markText({ ch: ruleRange[0].column, line: ruleRange[0].line }, {
                ch: ruleRange[1].column,
                line: ruleRange[1].line
            }, { replacedWith: this.domElement });
            this.hidden = false;
            this.editor.editorImplementation.on('change', this.changeEventFunction);
            this.editor.editorImplementation.on('cursorActivity', this.cursorActivityFunction);
        }
    };
    CodeMirrorRuleDecoration.prototype.hide = function () {
        if (!this.hidden) {
            this.mark.clear();
            this.hidden = true;
            this.mark = null;
        }
    };
    CodeMirrorRuleDecoration.prototype.remove = function () {
        if (this.mark) {
            this.hide();
            this.editor.editorImplementation.off('change', this.changeEventFunction);
            this.editor.editorImplementation.off('cursorActivity', this.cursorActivityFunction);
        }
    };
    CodeMirrorRuleDecoration.prototype.handleRuleWhenWithin = function () {
        if (this.clearOnEnter && this.mark) {
            this.hide();
        }
    };
    return CodeMirrorRuleDecoration;
}());
exports.CodeMirrorRuleDecoration = CodeMirrorRuleDecoration;
//# sourceMappingURL=codemirror-rule-decoration.js.map