"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var CodeMirrorTokenDecoration = /** @class */ (function () {
    function CodeMirrorTokenDecoration(editor, token, domElement) {
        var _this = this;
        this.editor = editor;
        this.token = token;
        this.domElement = domElement;
        this.clearOnEnter = true;
        this.toggleOnExit = true;
        this.hidden = false;
        var changed = false;
        this.cursorActivityFunction = function () {
            if (changed) {
                changed = false;
            }
            else if (_this.token.exists()) {
                var pos = _this.editor.getCursorPosition();
                var range = _this.token.getRange();
                if (_this.token.inRange(pos) || (range[1].line === pos.line && range[1].column === pos.column)) {
                    _this.handleRuleWhenWithin();
                }
                else {
                    if (_this.hidden && _this.toggleOnExit) {
                        _this.show();
                    }
                }
            }
        };
        this.changeEventFunction = function () {
            changed = true;
        };
        //
        // Make sure the rule exists, before defaulting on a show
        //
        if (this.editor.getDisplayDecorations()) {
            this.show();
            this.cursorActivityFunction();
        }
        else {
            this.hidden = true;
        }
    }
    CodeMirrorTokenDecoration.prototype.getToken = function () {
        return this.token;
    };
    CodeMirrorTokenDecoration.prototype.getDomElement = function () {
        return this.domElement;
    };
    CodeMirrorTokenDecoration.prototype.isHidden = function () {
        return this.hidden;
    };
    CodeMirrorTokenDecoration.prototype.show = function () {
        if (!this.mark) {
            var tokenRange = this.token.getRange();
            this.mark = this.editor.editorImplementation.getDoc()
                .markText({ ch: tokenRange[0].column, line: tokenRange[0].line }, {
                ch: tokenRange[1].column,
                line: tokenRange[1].line
            }, { replacedWith: this.domElement });
            this.hidden = false;
            this.editor.editorImplementation.on('change', this.changeEventFunction);
            this.editor.editorImplementation.on('cursorActivity', this.cursorActivityFunction);
        }
    };
    CodeMirrorTokenDecoration.prototype.hide = function () {
        if (!this.hidden) {
            this.mark.clear();
            this.hidden = true;
            this.mark = null;
        }
    };
    CodeMirrorTokenDecoration.prototype.remove = function () {
        if (this.mark) {
            this.hide();
            this.editor.editorImplementation.off('change', this.changeEventFunction);
            this.editor.editorImplementation.off('cursorActivity', this.cursorActivityFunction);
        }
    };
    CodeMirrorTokenDecoration.prototype.handleRuleWhenWithin = function () {
        if (this.clearOnEnter && this.mark) {
            this.hide();
        }
    };
    return CodeMirrorTokenDecoration;
}());
exports.CodeMirrorTokenDecoration = CodeMirrorTokenDecoration;
//# sourceMappingURL=codemirror-token-decoration.js.map